# DiffValueChangeLong


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**new_value** | **int** |  | [optional] 
**old_value** | **int** |  | [optional] 

## Example

```python
from src.client.generated.models.diff_value_change_long import DiffValueChangeLong

# TODO update the JSON string below
json = "{}"
# create an instance of DiffValueChangeLong from a JSON string
diff_value_change_long_instance = DiffValueChangeLong.from_json(json)
# print the JSON string representation of the object
print(DiffValueChangeLong.to_json())

# convert the object into a dict
diff_value_change_long_dict = diff_value_change_long_instance.to_dict()
# create an instance of DiffValueChangeLong from a dict
diff_value_change_long_from_dict = DiffValueChangeLong.from_dict(diff_value_change_long_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


